# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RemediationArgs', 'Remediation']

@pulumi.input_type
class RemediationArgs:
    def __init__(__self__, *,
                 config_rule_id: pulumi.Input[str],
                 invoke_type: pulumi.Input[str],
                 params: pulumi.Input[str],
                 remediation_template_id: pulumi.Input[str],
                 remediation_type: pulumi.Input[str],
                 remediation_source_type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Remediation resource.
        :param pulumi.Input[str] config_rule_id: Rule ID.
        :param pulumi.Input[str] invoke_type: Execution type, valid values: `Manual`, `Automatic`.
        :param pulumi.Input[str] params: Remediation parameter.
        :param pulumi.Input[str] remediation_template_id: Remediation template ID.
        :param pulumi.Input[str] remediation_type: Remediation type, valid values: `OOS`, `FC`.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        :param pulumi.Input[str] remediation_source_type: Remediation resource type, valid values: `ALIYUN` , `CUSTOMER`.
        """
        pulumi.set(__self__, "config_rule_id", config_rule_id)
        pulumi.set(__self__, "invoke_type", invoke_type)
        pulumi.set(__self__, "params", params)
        pulumi.set(__self__, "remediation_template_id", remediation_template_id)
        pulumi.set(__self__, "remediation_type", remediation_type)
        if remediation_source_type is not None:
            pulumi.set(__self__, "remediation_source_type", remediation_source_type)

    @property
    @pulumi.getter(name="configRuleId")
    def config_rule_id(self) -> pulumi.Input[str]:
        """
        Rule ID.
        """
        return pulumi.get(self, "config_rule_id")

    @config_rule_id.setter
    def config_rule_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "config_rule_id", value)

    @property
    @pulumi.getter(name="invokeType")
    def invoke_type(self) -> pulumi.Input[str]:
        """
        Execution type, valid values: `Manual`, `Automatic`.
        """
        return pulumi.get(self, "invoke_type")

    @invoke_type.setter
    def invoke_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "invoke_type", value)

    @property
    @pulumi.getter
    def params(self) -> pulumi.Input[str]:
        """
        Remediation parameter.
        """
        return pulumi.get(self, "params")

    @params.setter
    def params(self, value: pulumi.Input[str]):
        pulumi.set(self, "params", value)

    @property
    @pulumi.getter(name="remediationTemplateId")
    def remediation_template_id(self) -> pulumi.Input[str]:
        """
        Remediation template ID.
        """
        return pulumi.get(self, "remediation_template_id")

    @remediation_template_id.setter
    def remediation_template_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "remediation_template_id", value)

    @property
    @pulumi.getter(name="remediationType")
    def remediation_type(self) -> pulumi.Input[str]:
        """
        Remediation type, valid values: `OOS`, `FC`.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "remediation_type")

    @remediation_type.setter
    def remediation_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "remediation_type", value)

    @property
    @pulumi.getter(name="remediationSourceType")
    def remediation_source_type(self) -> Optional[pulumi.Input[str]]:
        """
        Remediation resource type, valid values: `ALIYUN` , `CUSTOMER`.
        """
        return pulumi.get(self, "remediation_source_type")

    @remediation_source_type.setter
    def remediation_source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remediation_source_type", value)


@pulumi.input_type
class _RemediationState:
    def __init__(__self__, *,
                 config_rule_id: Optional[pulumi.Input[str]] = None,
                 invoke_type: Optional[pulumi.Input[str]] = None,
                 params: Optional[pulumi.Input[str]] = None,
                 remediation_id: Optional[pulumi.Input[str]] = None,
                 remediation_source_type: Optional[pulumi.Input[str]] = None,
                 remediation_template_id: Optional[pulumi.Input[str]] = None,
                 remediation_type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Remediation resources.
        :param pulumi.Input[str] config_rule_id: Rule ID.
        :param pulumi.Input[str] invoke_type: Execution type, valid values: `Manual`, `Automatic`.
        :param pulumi.Input[str] params: Remediation parameter.
        :param pulumi.Input[str] remediation_id: Remediation ID.
        :param pulumi.Input[str] remediation_source_type: Remediation resource type, valid values: `ALIYUN` , `CUSTOMER`.
        :param pulumi.Input[str] remediation_template_id: Remediation template ID.
        :param pulumi.Input[str] remediation_type: Remediation type, valid values: `OOS`, `FC`.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        if config_rule_id is not None:
            pulumi.set(__self__, "config_rule_id", config_rule_id)
        if invoke_type is not None:
            pulumi.set(__self__, "invoke_type", invoke_type)
        if params is not None:
            pulumi.set(__self__, "params", params)
        if remediation_id is not None:
            pulumi.set(__self__, "remediation_id", remediation_id)
        if remediation_source_type is not None:
            pulumi.set(__self__, "remediation_source_type", remediation_source_type)
        if remediation_template_id is not None:
            pulumi.set(__self__, "remediation_template_id", remediation_template_id)
        if remediation_type is not None:
            pulumi.set(__self__, "remediation_type", remediation_type)

    @property
    @pulumi.getter(name="configRuleId")
    def config_rule_id(self) -> Optional[pulumi.Input[str]]:
        """
        Rule ID.
        """
        return pulumi.get(self, "config_rule_id")

    @config_rule_id.setter
    def config_rule_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "config_rule_id", value)

    @property
    @pulumi.getter(name="invokeType")
    def invoke_type(self) -> Optional[pulumi.Input[str]]:
        """
        Execution type, valid values: `Manual`, `Automatic`.
        """
        return pulumi.get(self, "invoke_type")

    @invoke_type.setter
    def invoke_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "invoke_type", value)

    @property
    @pulumi.getter
    def params(self) -> Optional[pulumi.Input[str]]:
        """
        Remediation parameter.
        """
        return pulumi.get(self, "params")

    @params.setter
    def params(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "params", value)

    @property
    @pulumi.getter(name="remediationId")
    def remediation_id(self) -> Optional[pulumi.Input[str]]:
        """
        Remediation ID.
        """
        return pulumi.get(self, "remediation_id")

    @remediation_id.setter
    def remediation_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remediation_id", value)

    @property
    @pulumi.getter(name="remediationSourceType")
    def remediation_source_type(self) -> Optional[pulumi.Input[str]]:
        """
        Remediation resource type, valid values: `ALIYUN` , `CUSTOMER`.
        """
        return pulumi.get(self, "remediation_source_type")

    @remediation_source_type.setter
    def remediation_source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remediation_source_type", value)

    @property
    @pulumi.getter(name="remediationTemplateId")
    def remediation_template_id(self) -> Optional[pulumi.Input[str]]:
        """
        Remediation template ID.
        """
        return pulumi.get(self, "remediation_template_id")

    @remediation_template_id.setter
    def remediation_template_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remediation_template_id", value)

    @property
    @pulumi.getter(name="remediationType")
    def remediation_type(self) -> Optional[pulumi.Input[str]]:
        """
        Remediation type, valid values: `OOS`, `FC`.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "remediation_type")

    @remediation_type.setter
    def remediation_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remediation_type", value)


class Remediation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_rule_id: Optional[pulumi.Input[str]] = None,
                 invoke_type: Optional[pulumi.Input[str]] = None,
                 params: Optional[pulumi.Input[str]] = None,
                 remediation_source_type: Optional[pulumi.Input[str]] = None,
                 remediation_template_id: Optional[pulumi.Input[str]] = None,
                 remediation_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Config Remediation resource.

        For information about Config Remediation and how to use it, see [What is Remediation](https://www.alibabacloud.com/help/en/cloud-config/latest/api-config-2020-09-07-createremediation).

        > **NOTE:** Available since v1.204.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example-oss"
        default = alicloud.get_regions(current=True)
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_bucket = alicloud.oss.Bucket("default",
            bucket=f"{name}-{default_integer['result']}",
            tags={
                "For": "example",
            })
        name_bucket_acl = alicloud.oss.BucketAcl("name",
            bucket=default_bucket.bucket,
            acl="public-read")
        default_rule = alicloud.cfg.Rule("default",
            description="If the ACL policy of the OSS bucket denies read access from the Internet, the configuration is considered compliant.",
            source_owner="ALIYUN",
            source_identifier="oss-bucket-public-read-prohibited",
            risk_level=1,
            tag_key_scope="For",
            tag_value_scope="example",
            region_ids_scope=default.regions[0].id,
            config_rule_trigger_types="ConfigurationItemChangeNotification",
            resource_types_scopes=["ACS::OSS::Bucket"],
            rule_name="oss-bucket-public-read-prohibited")
        default_remediation = alicloud.cfg.Remediation("default",
            config_rule_id=default_rule.config_rule_id,
            remediation_template_id="ACS-OSS-PutBucketAcl",
            remediation_source_type="ALIYUN",
            invoke_type="MANUAL_EXECUTION",
            params=default_bucket.bucket.apply(lambda bucket: f"{{\\"bucketName\\": \\"{bucket}\\", \\"regionId\\": \\"{default.regions[0].id}\\", \\"permissionName\\": \\"private\\"}}"),
            remediation_type="OOS")
        ```

        ## Import

        Config Remediation can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cfg/remediation:Remediation example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] config_rule_id: Rule ID.
        :param pulumi.Input[str] invoke_type: Execution type, valid values: `Manual`, `Automatic`.
        :param pulumi.Input[str] params: Remediation parameter.
        :param pulumi.Input[str] remediation_source_type: Remediation resource type, valid values: `ALIYUN` , `CUSTOMER`.
        :param pulumi.Input[str] remediation_template_id: Remediation template ID.
        :param pulumi.Input[str] remediation_type: Remediation type, valid values: `OOS`, `FC`.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RemediationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Config Remediation resource.

        For information about Config Remediation and how to use it, see [What is Remediation](https://www.alibabacloud.com/help/en/cloud-config/latest/api-config-2020-09-07-createremediation).

        > **NOTE:** Available since v1.204.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example-oss"
        default = alicloud.get_regions(current=True)
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_bucket = alicloud.oss.Bucket("default",
            bucket=f"{name}-{default_integer['result']}",
            tags={
                "For": "example",
            })
        name_bucket_acl = alicloud.oss.BucketAcl("name",
            bucket=default_bucket.bucket,
            acl="public-read")
        default_rule = alicloud.cfg.Rule("default",
            description="If the ACL policy of the OSS bucket denies read access from the Internet, the configuration is considered compliant.",
            source_owner="ALIYUN",
            source_identifier="oss-bucket-public-read-prohibited",
            risk_level=1,
            tag_key_scope="For",
            tag_value_scope="example",
            region_ids_scope=default.regions[0].id,
            config_rule_trigger_types="ConfigurationItemChangeNotification",
            resource_types_scopes=["ACS::OSS::Bucket"],
            rule_name="oss-bucket-public-read-prohibited")
        default_remediation = alicloud.cfg.Remediation("default",
            config_rule_id=default_rule.config_rule_id,
            remediation_template_id="ACS-OSS-PutBucketAcl",
            remediation_source_type="ALIYUN",
            invoke_type="MANUAL_EXECUTION",
            params=default_bucket.bucket.apply(lambda bucket: f"{{\\"bucketName\\": \\"{bucket}\\", \\"regionId\\": \\"{default.regions[0].id}\\", \\"permissionName\\": \\"private\\"}}"),
            remediation_type="OOS")
        ```

        ## Import

        Config Remediation can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cfg/remediation:Remediation example <id>
        ```

        :param str resource_name: The name of the resource.
        :param RemediationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RemediationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_rule_id: Optional[pulumi.Input[str]] = None,
                 invoke_type: Optional[pulumi.Input[str]] = None,
                 params: Optional[pulumi.Input[str]] = None,
                 remediation_source_type: Optional[pulumi.Input[str]] = None,
                 remediation_template_id: Optional[pulumi.Input[str]] = None,
                 remediation_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RemediationArgs.__new__(RemediationArgs)

            if config_rule_id is None and not opts.urn:
                raise TypeError("Missing required property 'config_rule_id'")
            __props__.__dict__["config_rule_id"] = config_rule_id
            if invoke_type is None and not opts.urn:
                raise TypeError("Missing required property 'invoke_type'")
            __props__.__dict__["invoke_type"] = invoke_type
            if params is None and not opts.urn:
                raise TypeError("Missing required property 'params'")
            __props__.__dict__["params"] = params
            __props__.__dict__["remediation_source_type"] = remediation_source_type
            if remediation_template_id is None and not opts.urn:
                raise TypeError("Missing required property 'remediation_template_id'")
            __props__.__dict__["remediation_template_id"] = remediation_template_id
            if remediation_type is None and not opts.urn:
                raise TypeError("Missing required property 'remediation_type'")
            __props__.__dict__["remediation_type"] = remediation_type
            __props__.__dict__["remediation_id"] = None
        super(Remediation, __self__).__init__(
            'alicloud:cfg/remediation:Remediation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_rule_id: Optional[pulumi.Input[str]] = None,
            invoke_type: Optional[pulumi.Input[str]] = None,
            params: Optional[pulumi.Input[str]] = None,
            remediation_id: Optional[pulumi.Input[str]] = None,
            remediation_source_type: Optional[pulumi.Input[str]] = None,
            remediation_template_id: Optional[pulumi.Input[str]] = None,
            remediation_type: Optional[pulumi.Input[str]] = None) -> 'Remediation':
        """
        Get an existing Remediation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] config_rule_id: Rule ID.
        :param pulumi.Input[str] invoke_type: Execution type, valid values: `Manual`, `Automatic`.
        :param pulumi.Input[str] params: Remediation parameter.
        :param pulumi.Input[str] remediation_id: Remediation ID.
        :param pulumi.Input[str] remediation_source_type: Remediation resource type, valid values: `ALIYUN` , `CUSTOMER`.
        :param pulumi.Input[str] remediation_template_id: Remediation template ID.
        :param pulumi.Input[str] remediation_type: Remediation type, valid values: `OOS`, `FC`.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RemediationState.__new__(_RemediationState)

        __props__.__dict__["config_rule_id"] = config_rule_id
        __props__.__dict__["invoke_type"] = invoke_type
        __props__.__dict__["params"] = params
        __props__.__dict__["remediation_id"] = remediation_id
        __props__.__dict__["remediation_source_type"] = remediation_source_type
        __props__.__dict__["remediation_template_id"] = remediation_template_id
        __props__.__dict__["remediation_type"] = remediation_type
        return Remediation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configRuleId")
    def config_rule_id(self) -> pulumi.Output[str]:
        """
        Rule ID.
        """
        return pulumi.get(self, "config_rule_id")

    @property
    @pulumi.getter(name="invokeType")
    def invoke_type(self) -> pulumi.Output[str]:
        """
        Execution type, valid values: `Manual`, `Automatic`.
        """
        return pulumi.get(self, "invoke_type")

    @property
    @pulumi.getter
    def params(self) -> pulumi.Output[str]:
        """
        Remediation parameter.
        """
        return pulumi.get(self, "params")

    @property
    @pulumi.getter(name="remediationId")
    def remediation_id(self) -> pulumi.Output[str]:
        """
        Remediation ID.
        """
        return pulumi.get(self, "remediation_id")

    @property
    @pulumi.getter(name="remediationSourceType")
    def remediation_source_type(self) -> pulumi.Output[str]:
        """
        Remediation resource type, valid values: `ALIYUN` , `CUSTOMER`.
        """
        return pulumi.get(self, "remediation_source_type")

    @property
    @pulumi.getter(name="remediationTemplateId")
    def remediation_template_id(self) -> pulumi.Output[str]:
        """
        Remediation template ID.
        """
        return pulumi.get(self, "remediation_template_id")

    @property
    @pulumi.getter(name="remediationType")
    def remediation_type(self) -> pulumi.Output[str]:
        """
        Remediation type, valid values: `OOS`, `FC`.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "remediation_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['OssShipperArgs', 'OssShipper']

@pulumi.input_type
class OssShipperArgs:
    def __init__(__self__, *,
                 buffer_interval: pulumi.Input[int],
                 buffer_size: pulumi.Input[int],
                 format: pulumi.Input[str],
                 logstore_name: pulumi.Input[str],
                 oss_bucket: pulumi.Input[str],
                 path_format: pulumi.Input[str],
                 project_name: pulumi.Input[str],
                 shipper_name: pulumi.Input[str],
                 compress_type: Optional[pulumi.Input[str]] = None,
                 csv_config_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 csv_config_delimiter: Optional[pulumi.Input[str]] = None,
                 csv_config_header: Optional[pulumi.Input[bool]] = None,
                 csv_config_linefeed: Optional[pulumi.Input[str]] = None,
                 csv_config_nullidentifier: Optional[pulumi.Input[str]] = None,
                 csv_config_quote: Optional[pulumi.Input[str]] = None,
                 json_enable_tag: Optional[pulumi.Input[bool]] = None,
                 oss_prefix: Optional[pulumi.Input[str]] = None,
                 parquet_configs: Optional[pulumi.Input[Sequence[pulumi.Input['OssShipperParquetConfigArgs']]]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a OssShipper resource.
        :param pulumi.Input[int] buffer_interval: How often is it delivered every interval.
        :param pulumi.Input[int] buffer_size: Automatically control the creation interval of delivery tasks and set the upper limit of an OSS object size (calculated in uncompressed), unit: `MB`.
        :param pulumi.Input[str] format: Storage format, only supports three types: `json`, `parquet`, `csv`.
               **According to the different format, please select the following parameters**
               - format = `json`
               `json_enable_tag` - (Optional) Whether to deliver the label.
               - format = `csv`
               `csv_config_delimiter` - (Optional) Separator configuration in csv configuration format.
               `csv_config_columns` - (Optional) Field configuration in csv configuration format.
               `csv_config_nullidentifier` - (Optional) Invalid field content.
               `csv_config_quote` - (Optional) Escape character under csv configuration.
               `csv_config_header` - (Optional) Indicates whether to write the field name to the CSV file, the default value is `false`.
               `csv_config_linefeed` - (Optional) lineFeed in csv configuration.
               - format = `parquet`
               `parquet_config` - (Optional) Configure to use parquet storage format.
               `name` - (Required) The name of the key.
               `type` - (Required) Type of configuration name.
        :param pulumi.Input[str] logstore_name: The name of the log logstore.
        :param pulumi.Input[str] oss_bucket: The name of the oss bucket.
        :param pulumi.Input[str] path_format: The OSS Bucket directory is dynamically generated according to the creation time of the shipper task, it cannot start with a forward slash `/`, the default value is `%Y/%m/%d/%H/%M`.
        :param pulumi.Input[str] project_name: The name of the log project. It is the only in one Alicloud account.
        :param pulumi.Input[str] shipper_name: Delivery configuration name, it can only contain lowercase letters, numbers, dashes `-` and underscores `_`. It must start and end with lowercase letters or numbers, and the name must be 2 to 128 characters long.
        :param pulumi.Input[str] compress_type: OSS data storage compression method, support: none, snappy. Among them, none means that the original data is not compressed, and snappy means that the data is compressed using the snappy algorithm, which can reduce the storage space usage of the `OSS Bucket`.
        :param pulumi.Input[str] oss_prefix: The data synchronized from Log Service to OSS will be stored in this directory of Bucket.
        :param pulumi.Input[str] role_arn: Used for access control, the OSS Bucket owner creates the role mark, such as `acs:ram::13234:role/logrole`
        """
        pulumi.set(__self__, "buffer_interval", buffer_interval)
        pulumi.set(__self__, "buffer_size", buffer_size)
        pulumi.set(__self__, "format", format)
        pulumi.set(__self__, "logstore_name", logstore_name)
        pulumi.set(__self__, "oss_bucket", oss_bucket)
        pulumi.set(__self__, "path_format", path_format)
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "shipper_name", shipper_name)
        if compress_type is not None:
            pulumi.set(__self__, "compress_type", compress_type)
        if csv_config_columns is not None:
            pulumi.set(__self__, "csv_config_columns", csv_config_columns)
        if csv_config_delimiter is not None:
            pulumi.set(__self__, "csv_config_delimiter", csv_config_delimiter)
        if csv_config_header is not None:
            pulumi.set(__self__, "csv_config_header", csv_config_header)
        if csv_config_linefeed is not None:
            pulumi.set(__self__, "csv_config_linefeed", csv_config_linefeed)
        if csv_config_nullidentifier is not None:
            pulumi.set(__self__, "csv_config_nullidentifier", csv_config_nullidentifier)
        if csv_config_quote is not None:
            pulumi.set(__self__, "csv_config_quote", csv_config_quote)
        if json_enable_tag is not None:
            pulumi.set(__self__, "json_enable_tag", json_enable_tag)
        if oss_prefix is not None:
            pulumi.set(__self__, "oss_prefix", oss_prefix)
        if parquet_configs is not None:
            pulumi.set(__self__, "parquet_configs", parquet_configs)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)

    @property
    @pulumi.getter(name="bufferInterval")
    def buffer_interval(self) -> pulumi.Input[int]:
        """
        How often is it delivered every interval.
        """
        return pulumi.get(self, "buffer_interval")

    @buffer_interval.setter
    def buffer_interval(self, value: pulumi.Input[int]):
        pulumi.set(self, "buffer_interval", value)

    @property
    @pulumi.getter(name="bufferSize")
    def buffer_size(self) -> pulumi.Input[int]:
        """
        Automatically control the creation interval of delivery tasks and set the upper limit of an OSS object size (calculated in uncompressed), unit: `MB`.
        """
        return pulumi.get(self, "buffer_size")

    @buffer_size.setter
    def buffer_size(self, value: pulumi.Input[int]):
        pulumi.set(self, "buffer_size", value)

    @property
    @pulumi.getter
    def format(self) -> pulumi.Input[str]:
        """
        Storage format, only supports three types: `json`, `parquet`, `csv`.
        **According to the different format, please select the following parameters**
        - format = `json`
        `json_enable_tag` - (Optional) Whether to deliver the label.
        - format = `csv`
        `csv_config_delimiter` - (Optional) Separator configuration in csv configuration format.
        `csv_config_columns` - (Optional) Field configuration in csv configuration format.
        `csv_config_nullidentifier` - (Optional) Invalid field content.
        `csv_config_quote` - (Optional) Escape character under csv configuration.
        `csv_config_header` - (Optional) Indicates whether to write the field name to the CSV file, the default value is `false`.
        `csv_config_linefeed` - (Optional) lineFeed in csv configuration.
        - format = `parquet`
        `parquet_config` - (Optional) Configure to use parquet storage format.
        `name` - (Required) The name of the key.
        `type` - (Required) Type of configuration name.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: pulumi.Input[str]):
        pulumi.set(self, "format", value)

    @property
    @pulumi.getter(name="logstoreName")
    def logstore_name(self) -> pulumi.Input[str]:
        """
        The name of the log logstore.
        """
        return pulumi.get(self, "logstore_name")

    @logstore_name.setter
    def logstore_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "logstore_name", value)

    @property
    @pulumi.getter(name="ossBucket")
    def oss_bucket(self) -> pulumi.Input[str]:
        """
        The name of the oss bucket.
        """
        return pulumi.get(self, "oss_bucket")

    @oss_bucket.setter
    def oss_bucket(self, value: pulumi.Input[str]):
        pulumi.set(self, "oss_bucket", value)

    @property
    @pulumi.getter(name="pathFormat")
    def path_format(self) -> pulumi.Input[str]:
        """
        The OSS Bucket directory is dynamically generated according to the creation time of the shipper task, it cannot start with a forward slash `/`, the default value is `%Y/%m/%d/%H/%M`.
        """
        return pulumi.get(self, "path_format")

    @path_format.setter
    def path_format(self, value: pulumi.Input[str]):
        pulumi.set(self, "path_format", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[str]:
        """
        The name of the log project. It is the only in one Alicloud account.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="shipperName")
    def shipper_name(self) -> pulumi.Input[str]:
        """
        Delivery configuration name, it can only contain lowercase letters, numbers, dashes `-` and underscores `_`. It must start and end with lowercase letters or numbers, and the name must be 2 to 128 characters long.
        """
        return pulumi.get(self, "shipper_name")

    @shipper_name.setter
    def shipper_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "shipper_name", value)

    @property
    @pulumi.getter(name="compressType")
    def compress_type(self) -> Optional[pulumi.Input[str]]:
        """
        OSS data storage compression method, support: none, snappy. Among them, none means that the original data is not compressed, and snappy means that the data is compressed using the snappy algorithm, which can reduce the storage space usage of the `OSS Bucket`.
        """
        return pulumi.get(self, "compress_type")

    @compress_type.setter
    def compress_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compress_type", value)

    @property
    @pulumi.getter(name="csvConfigColumns")
    def csv_config_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "csv_config_columns")

    @csv_config_columns.setter
    def csv_config_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "csv_config_columns", value)

    @property
    @pulumi.getter(name="csvConfigDelimiter")
    def csv_config_delimiter(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "csv_config_delimiter")

    @csv_config_delimiter.setter
    def csv_config_delimiter(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "csv_config_delimiter", value)

    @property
    @pulumi.getter(name="csvConfigHeader")
    def csv_config_header(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "csv_config_header")

    @csv_config_header.setter
    def csv_config_header(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "csv_config_header", value)

    @property
    @pulumi.getter(name="csvConfigLinefeed")
    def csv_config_linefeed(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "csv_config_linefeed")

    @csv_config_linefeed.setter
    def csv_config_linefeed(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "csv_config_linefeed", value)

    @property
    @pulumi.getter(name="csvConfigNullidentifier")
    def csv_config_nullidentifier(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "csv_config_nullidentifier")

    @csv_config_nullidentifier.setter
    def csv_config_nullidentifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "csv_config_nullidentifier", value)

    @property
    @pulumi.getter(name="csvConfigQuote")
    def csv_config_quote(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "csv_config_quote")

    @csv_config_quote.setter
    def csv_config_quote(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "csv_config_quote", value)

    @property
    @pulumi.getter(name="jsonEnableTag")
    def json_enable_tag(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "json_enable_tag")

    @json_enable_tag.setter
    def json_enable_tag(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "json_enable_tag", value)

    @property
    @pulumi.getter(name="ossPrefix")
    def oss_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        The data synchronized from Log Service to OSS will be stored in this directory of Bucket.
        """
        return pulumi.get(self, "oss_prefix")

    @oss_prefix.setter
    def oss_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oss_prefix", value)

    @property
    @pulumi.getter(name="parquetConfigs")
    def parquet_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['OssShipperParquetConfigArgs']]]]:
        return pulumi.get(self, "parquet_configs")

    @parquet_configs.setter
    def parquet_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['OssShipperParquetConfigArgs']]]]):
        pulumi.set(self, "parquet_configs", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        Used for access control, the OSS Bucket owner creates the role mark, such as `acs:ram::13234:role/logrole`
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_arn", value)


@pulumi.input_type
class _OssShipperState:
    def __init__(__self__, *,
                 buffer_interval: Optional[pulumi.Input[int]] = None,
                 buffer_size: Optional[pulumi.Input[int]] = None,
                 compress_type: Optional[pulumi.Input[str]] = None,
                 csv_config_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 csv_config_delimiter: Optional[pulumi.Input[str]] = None,
                 csv_config_header: Optional[pulumi.Input[bool]] = None,
                 csv_config_linefeed: Optional[pulumi.Input[str]] = None,
                 csv_config_nullidentifier: Optional[pulumi.Input[str]] = None,
                 csv_config_quote: Optional[pulumi.Input[str]] = None,
                 format: Optional[pulumi.Input[str]] = None,
                 json_enable_tag: Optional[pulumi.Input[bool]] = None,
                 logstore_name: Optional[pulumi.Input[str]] = None,
                 oss_bucket: Optional[pulumi.Input[str]] = None,
                 oss_prefix: Optional[pulumi.Input[str]] = None,
                 parquet_configs: Optional[pulumi.Input[Sequence[pulumi.Input['OssShipperParquetConfigArgs']]]] = None,
                 path_format: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 shipper_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering OssShipper resources.
        :param pulumi.Input[int] buffer_interval: How often is it delivered every interval.
        :param pulumi.Input[int] buffer_size: Automatically control the creation interval of delivery tasks and set the upper limit of an OSS object size (calculated in uncompressed), unit: `MB`.
        :param pulumi.Input[str] compress_type: OSS data storage compression method, support: none, snappy. Among them, none means that the original data is not compressed, and snappy means that the data is compressed using the snappy algorithm, which can reduce the storage space usage of the `OSS Bucket`.
        :param pulumi.Input[str] format: Storage format, only supports three types: `json`, `parquet`, `csv`.
               **According to the different format, please select the following parameters**
               - format = `json`
               `json_enable_tag` - (Optional) Whether to deliver the label.
               - format = `csv`
               `csv_config_delimiter` - (Optional) Separator configuration in csv configuration format.
               `csv_config_columns` - (Optional) Field configuration in csv configuration format.
               `csv_config_nullidentifier` - (Optional) Invalid field content.
               `csv_config_quote` - (Optional) Escape character under csv configuration.
               `csv_config_header` - (Optional) Indicates whether to write the field name to the CSV file, the default value is `false`.
               `csv_config_linefeed` - (Optional) lineFeed in csv configuration.
               - format = `parquet`
               `parquet_config` - (Optional) Configure to use parquet storage format.
               `name` - (Required) The name of the key.
               `type` - (Required) Type of configuration name.
        :param pulumi.Input[str] logstore_name: The name of the log logstore.
        :param pulumi.Input[str] oss_bucket: The name of the oss bucket.
        :param pulumi.Input[str] oss_prefix: The data synchronized from Log Service to OSS will be stored in this directory of Bucket.
        :param pulumi.Input[str] path_format: The OSS Bucket directory is dynamically generated according to the creation time of the shipper task, it cannot start with a forward slash `/`, the default value is `%Y/%m/%d/%H/%M`.
        :param pulumi.Input[str] project_name: The name of the log project. It is the only in one Alicloud account.
        :param pulumi.Input[str] role_arn: Used for access control, the OSS Bucket owner creates the role mark, such as `acs:ram::13234:role/logrole`
        :param pulumi.Input[str] shipper_name: Delivery configuration name, it can only contain lowercase letters, numbers, dashes `-` and underscores `_`. It must start and end with lowercase letters or numbers, and the name must be 2 to 128 characters long.
        """
        if buffer_interval is not None:
            pulumi.set(__self__, "buffer_interval", buffer_interval)
        if buffer_size is not None:
            pulumi.set(__self__, "buffer_size", buffer_size)
        if compress_type is not None:
            pulumi.set(__self__, "compress_type", compress_type)
        if csv_config_columns is not None:
            pulumi.set(__self__, "csv_config_columns", csv_config_columns)
        if csv_config_delimiter is not None:
            pulumi.set(__self__, "csv_config_delimiter", csv_config_delimiter)
        if csv_config_header is not None:
            pulumi.set(__self__, "csv_config_header", csv_config_header)
        if csv_config_linefeed is not None:
            pulumi.set(__self__, "csv_config_linefeed", csv_config_linefeed)
        if csv_config_nullidentifier is not None:
            pulumi.set(__self__, "csv_config_nullidentifier", csv_config_nullidentifier)
        if csv_config_quote is not None:
            pulumi.set(__self__, "csv_config_quote", csv_config_quote)
        if format is not None:
            pulumi.set(__self__, "format", format)
        if json_enable_tag is not None:
            pulumi.set(__self__, "json_enable_tag", json_enable_tag)
        if logstore_name is not None:
            pulumi.set(__self__, "logstore_name", logstore_name)
        if oss_bucket is not None:
            pulumi.set(__self__, "oss_bucket", oss_bucket)
        if oss_prefix is not None:
            pulumi.set(__self__, "oss_prefix", oss_prefix)
        if parquet_configs is not None:
            pulumi.set(__self__, "parquet_configs", parquet_configs)
        if path_format is not None:
            pulumi.set(__self__, "path_format", path_format)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if shipper_name is not None:
            pulumi.set(__self__, "shipper_name", shipper_name)

    @property
    @pulumi.getter(name="bufferInterval")
    def buffer_interval(self) -> Optional[pulumi.Input[int]]:
        """
        How often is it delivered every interval.
        """
        return pulumi.get(self, "buffer_interval")

    @buffer_interval.setter
    def buffer_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "buffer_interval", value)

    @property
    @pulumi.getter(name="bufferSize")
    def buffer_size(self) -> Optional[pulumi.Input[int]]:
        """
        Automatically control the creation interval of delivery tasks and set the upper limit of an OSS object size (calculated in uncompressed), unit: `MB`.
        """
        return pulumi.get(self, "buffer_size")

    @buffer_size.setter
    def buffer_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "buffer_size", value)

    @property
    @pulumi.getter(name="compressType")
    def compress_type(self) -> Optional[pulumi.Input[str]]:
        """
        OSS data storage compression method, support: none, snappy. Among them, none means that the original data is not compressed, and snappy means that the data is compressed using the snappy algorithm, which can reduce the storage space usage of the `OSS Bucket`.
        """
        return pulumi.get(self, "compress_type")

    @compress_type.setter
    def compress_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compress_type", value)

    @property
    @pulumi.getter(name="csvConfigColumns")
    def csv_config_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "csv_config_columns")

    @csv_config_columns.setter
    def csv_config_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "csv_config_columns", value)

    @property
    @pulumi.getter(name="csvConfigDelimiter")
    def csv_config_delimiter(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "csv_config_delimiter")

    @csv_config_delimiter.setter
    def csv_config_delimiter(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "csv_config_delimiter", value)

    @property
    @pulumi.getter(name="csvConfigHeader")
    def csv_config_header(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "csv_config_header")

    @csv_config_header.setter
    def csv_config_header(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "csv_config_header", value)

    @property
    @pulumi.getter(name="csvConfigLinefeed")
    def csv_config_linefeed(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "csv_config_linefeed")

    @csv_config_linefeed.setter
    def csv_config_linefeed(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "csv_config_linefeed", value)

    @property
    @pulumi.getter(name="csvConfigNullidentifier")
    def csv_config_nullidentifier(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "csv_config_nullidentifier")

    @csv_config_nullidentifier.setter
    def csv_config_nullidentifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "csv_config_nullidentifier", value)

    @property
    @pulumi.getter(name="csvConfigQuote")
    def csv_config_quote(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "csv_config_quote")

    @csv_config_quote.setter
    def csv_config_quote(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "csv_config_quote", value)

    @property
    @pulumi.getter
    def format(self) -> Optional[pulumi.Input[str]]:
        """
        Storage format, only supports three types: `json`, `parquet`, `csv`.
        **According to the different format, please select the following parameters**
        - format = `json`
        `json_enable_tag` - (Optional) Whether to deliver the label.
        - format = `csv`
        `csv_config_delimiter` - (Optional) Separator configuration in csv configuration format.
        `csv_config_columns` - (Optional) Field configuration in csv configuration format.
        `csv_config_nullidentifier` - (Optional) Invalid field content.
        `csv_config_quote` - (Optional) Escape character under csv configuration.
        `csv_config_header` - (Optional) Indicates whether to write the field name to the CSV file, the default value is `false`.
        `csv_config_linefeed` - (Optional) lineFeed in csv configuration.
        - format = `parquet`
        `parquet_config` - (Optional) Configure to use parquet storage format.
        `name` - (Required) The name of the key.
        `type` - (Required) Type of configuration name.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "format", value)

    @property
    @pulumi.getter(name="jsonEnableTag")
    def json_enable_tag(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "json_enable_tag")

    @json_enable_tag.setter
    def json_enable_tag(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "json_enable_tag", value)

    @property
    @pulumi.getter(name="logstoreName")
    def logstore_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the log logstore.
        """
        return pulumi.get(self, "logstore_name")

    @logstore_name.setter
    def logstore_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logstore_name", value)

    @property
    @pulumi.getter(name="ossBucket")
    def oss_bucket(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the oss bucket.
        """
        return pulumi.get(self, "oss_bucket")

    @oss_bucket.setter
    def oss_bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oss_bucket", value)

    @property
    @pulumi.getter(name="ossPrefix")
    def oss_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        The data synchronized from Log Service to OSS will be stored in this directory of Bucket.
        """
        return pulumi.get(self, "oss_prefix")

    @oss_prefix.setter
    def oss_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oss_prefix", value)

    @property
    @pulumi.getter(name="parquetConfigs")
    def parquet_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['OssShipperParquetConfigArgs']]]]:
        return pulumi.get(self, "parquet_configs")

    @parquet_configs.setter
    def parquet_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['OssShipperParquetConfigArgs']]]]):
        pulumi.set(self, "parquet_configs", value)

    @property
    @pulumi.getter(name="pathFormat")
    def path_format(self) -> Optional[pulumi.Input[str]]:
        """
        The OSS Bucket directory is dynamically generated according to the creation time of the shipper task, it cannot start with a forward slash `/`, the default value is `%Y/%m/%d/%H/%M`.
        """
        return pulumi.get(self, "path_format")

    @path_format.setter
    def path_format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path_format", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the log project. It is the only in one Alicloud account.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        Used for access control, the OSS Bucket owner creates the role mark, such as `acs:ram::13234:role/logrole`
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter(name="shipperName")
    def shipper_name(self) -> Optional[pulumi.Input[str]]:
        """
        Delivery configuration name, it can only contain lowercase letters, numbers, dashes `-` and underscores `_`. It must start and end with lowercase letters or numbers, and the name must be 2 to 128 characters long.
        """
        return pulumi.get(self, "shipper_name")

    @shipper_name.setter
    def shipper_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "shipper_name", value)


class OssShipper(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 buffer_interval: Optional[pulumi.Input[int]] = None,
                 buffer_size: Optional[pulumi.Input[int]] = None,
                 compress_type: Optional[pulumi.Input[str]] = None,
                 csv_config_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 csv_config_delimiter: Optional[pulumi.Input[str]] = None,
                 csv_config_header: Optional[pulumi.Input[bool]] = None,
                 csv_config_linefeed: Optional[pulumi.Input[str]] = None,
                 csv_config_nullidentifier: Optional[pulumi.Input[str]] = None,
                 csv_config_quote: Optional[pulumi.Input[str]] = None,
                 format: Optional[pulumi.Input[str]] = None,
                 json_enable_tag: Optional[pulumi.Input[bool]] = None,
                 logstore_name: Optional[pulumi.Input[str]] = None,
                 oss_bucket: Optional[pulumi.Input[str]] = None,
                 oss_prefix: Optional[pulumi.Input[str]] = None,
                 parquet_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['OssShipperParquetConfigArgs', 'OssShipperParquetConfigArgsDict']]]]] = None,
                 path_format: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 shipper_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Log service data delivery management, this service provides the function of delivering data in logstore to oss product storage.
        [Refer to details](https://www.alibabacloud.com/help/en/doc-detail/43724.htm).

        > **NOTE:** Available in 1.121.0+

        > **DEPRECATED:**  This resource has been deprecated from version `1.215.0`. Please use new resource alicloud_log_oss_export.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        example = alicloud.log.Project("example",
            name=f"terraform-example-{default['result']}",
            description="terraform-example",
            tags={
                "Created": "TF",
                "For": "example",
            })
        example_store = alicloud.log.Store("example",
            project=example.name,
            name="example-store",
            retention_period=3650,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_oss_shipper = alicloud.log.OssShipper("example",
            project_name=example.name,
            logstore_name=example_store.name,
            shipper_name="terraform-example",
            oss_bucket="example_bucket",
            oss_prefix="root",
            buffer_interval=300,
            buffer_size=250,
            compress_type="none",
            path_format="%Y/%m/%d/%H/%M",
            format="json",
            json_enable_tag=True)
        ```

        ## Import

        Log oss shipper can be imported using the id or name, e.g.

        ```sh
        $ pulumi import alicloud:log/ossShipper:OssShipper example tf-log-project:tf-log-logstore:tf-log-shipper
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] buffer_interval: How often is it delivered every interval.
        :param pulumi.Input[int] buffer_size: Automatically control the creation interval of delivery tasks and set the upper limit of an OSS object size (calculated in uncompressed), unit: `MB`.
        :param pulumi.Input[str] compress_type: OSS data storage compression method, support: none, snappy. Among them, none means that the original data is not compressed, and snappy means that the data is compressed using the snappy algorithm, which can reduce the storage space usage of the `OSS Bucket`.
        :param pulumi.Input[str] format: Storage format, only supports three types: `json`, `parquet`, `csv`.
               **According to the different format, please select the following parameters**
               - format = `json`
               `json_enable_tag` - (Optional) Whether to deliver the label.
               - format = `csv`
               `csv_config_delimiter` - (Optional) Separator configuration in csv configuration format.
               `csv_config_columns` - (Optional) Field configuration in csv configuration format.
               `csv_config_nullidentifier` - (Optional) Invalid field content.
               `csv_config_quote` - (Optional) Escape character under csv configuration.
               `csv_config_header` - (Optional) Indicates whether to write the field name to the CSV file, the default value is `false`.
               `csv_config_linefeed` - (Optional) lineFeed in csv configuration.
               - format = `parquet`
               `parquet_config` - (Optional) Configure to use parquet storage format.
               `name` - (Required) The name of the key.
               `type` - (Required) Type of configuration name.
        :param pulumi.Input[str] logstore_name: The name of the log logstore.
        :param pulumi.Input[str] oss_bucket: The name of the oss bucket.
        :param pulumi.Input[str] oss_prefix: The data synchronized from Log Service to OSS will be stored in this directory of Bucket.
        :param pulumi.Input[str] path_format: The OSS Bucket directory is dynamically generated according to the creation time of the shipper task, it cannot start with a forward slash `/`, the default value is `%Y/%m/%d/%H/%M`.
        :param pulumi.Input[str] project_name: The name of the log project. It is the only in one Alicloud account.
        :param pulumi.Input[str] role_arn: Used for access control, the OSS Bucket owner creates the role mark, such as `acs:ram::13234:role/logrole`
        :param pulumi.Input[str] shipper_name: Delivery configuration name, it can only contain lowercase letters, numbers, dashes `-` and underscores `_`. It must start and end with lowercase letters or numbers, and the name must be 2 to 128 characters long.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OssShipperArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Log service data delivery management, this service provides the function of delivering data in logstore to oss product storage.
        [Refer to details](https://www.alibabacloud.com/help/en/doc-detail/43724.htm).

        > **NOTE:** Available in 1.121.0+

        > **DEPRECATED:**  This resource has been deprecated from version `1.215.0`. Please use new resource alicloud_log_oss_export.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        example = alicloud.log.Project("example",
            name=f"terraform-example-{default['result']}",
            description="terraform-example",
            tags={
                "Created": "TF",
                "For": "example",
            })
        example_store = alicloud.log.Store("example",
            project=example.name,
            name="example-store",
            retention_period=3650,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_oss_shipper = alicloud.log.OssShipper("example",
            project_name=example.name,
            logstore_name=example_store.name,
            shipper_name="terraform-example",
            oss_bucket="example_bucket",
            oss_prefix="root",
            buffer_interval=300,
            buffer_size=250,
            compress_type="none",
            path_format="%Y/%m/%d/%H/%M",
            format="json",
            json_enable_tag=True)
        ```

        ## Import

        Log oss shipper can be imported using the id or name, e.g.

        ```sh
        $ pulumi import alicloud:log/ossShipper:OssShipper example tf-log-project:tf-log-logstore:tf-log-shipper
        ```

        :param str resource_name: The name of the resource.
        :param OssShipperArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OssShipperArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 buffer_interval: Optional[pulumi.Input[int]] = None,
                 buffer_size: Optional[pulumi.Input[int]] = None,
                 compress_type: Optional[pulumi.Input[str]] = None,
                 csv_config_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 csv_config_delimiter: Optional[pulumi.Input[str]] = None,
                 csv_config_header: Optional[pulumi.Input[bool]] = None,
                 csv_config_linefeed: Optional[pulumi.Input[str]] = None,
                 csv_config_nullidentifier: Optional[pulumi.Input[str]] = None,
                 csv_config_quote: Optional[pulumi.Input[str]] = None,
                 format: Optional[pulumi.Input[str]] = None,
                 json_enable_tag: Optional[pulumi.Input[bool]] = None,
                 logstore_name: Optional[pulumi.Input[str]] = None,
                 oss_bucket: Optional[pulumi.Input[str]] = None,
                 oss_prefix: Optional[pulumi.Input[str]] = None,
                 parquet_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['OssShipperParquetConfigArgs', 'OssShipperParquetConfigArgsDict']]]]] = None,
                 path_format: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 shipper_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OssShipperArgs.__new__(OssShipperArgs)

            if buffer_interval is None and not opts.urn:
                raise TypeError("Missing required property 'buffer_interval'")
            __props__.__dict__["buffer_interval"] = buffer_interval
            if buffer_size is None and not opts.urn:
                raise TypeError("Missing required property 'buffer_size'")
            __props__.__dict__["buffer_size"] = buffer_size
            __props__.__dict__["compress_type"] = compress_type
            __props__.__dict__["csv_config_columns"] = csv_config_columns
            __props__.__dict__["csv_config_delimiter"] = csv_config_delimiter
            __props__.__dict__["csv_config_header"] = csv_config_header
            __props__.__dict__["csv_config_linefeed"] = csv_config_linefeed
            __props__.__dict__["csv_config_nullidentifier"] = csv_config_nullidentifier
            __props__.__dict__["csv_config_quote"] = csv_config_quote
            if format is None and not opts.urn:
                raise TypeError("Missing required property 'format'")
            __props__.__dict__["format"] = format
            __props__.__dict__["json_enable_tag"] = json_enable_tag
            if logstore_name is None and not opts.urn:
                raise TypeError("Missing required property 'logstore_name'")
            __props__.__dict__["logstore_name"] = logstore_name
            if oss_bucket is None and not opts.urn:
                raise TypeError("Missing required property 'oss_bucket'")
            __props__.__dict__["oss_bucket"] = oss_bucket
            __props__.__dict__["oss_prefix"] = oss_prefix
            __props__.__dict__["parquet_configs"] = parquet_configs
            if path_format is None and not opts.urn:
                raise TypeError("Missing required property 'path_format'")
            __props__.__dict__["path_format"] = path_format
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["role_arn"] = role_arn
            if shipper_name is None and not opts.urn:
                raise TypeError("Missing required property 'shipper_name'")
            __props__.__dict__["shipper_name"] = shipper_name
        super(OssShipper, __self__).__init__(
            'alicloud:log/ossShipper:OssShipper',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            buffer_interval: Optional[pulumi.Input[int]] = None,
            buffer_size: Optional[pulumi.Input[int]] = None,
            compress_type: Optional[pulumi.Input[str]] = None,
            csv_config_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            csv_config_delimiter: Optional[pulumi.Input[str]] = None,
            csv_config_header: Optional[pulumi.Input[bool]] = None,
            csv_config_linefeed: Optional[pulumi.Input[str]] = None,
            csv_config_nullidentifier: Optional[pulumi.Input[str]] = None,
            csv_config_quote: Optional[pulumi.Input[str]] = None,
            format: Optional[pulumi.Input[str]] = None,
            json_enable_tag: Optional[pulumi.Input[bool]] = None,
            logstore_name: Optional[pulumi.Input[str]] = None,
            oss_bucket: Optional[pulumi.Input[str]] = None,
            oss_prefix: Optional[pulumi.Input[str]] = None,
            parquet_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['OssShipperParquetConfigArgs', 'OssShipperParquetConfigArgsDict']]]]] = None,
            path_format: Optional[pulumi.Input[str]] = None,
            project_name: Optional[pulumi.Input[str]] = None,
            role_arn: Optional[pulumi.Input[str]] = None,
            shipper_name: Optional[pulumi.Input[str]] = None) -> 'OssShipper':
        """
        Get an existing OssShipper resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] buffer_interval: How often is it delivered every interval.
        :param pulumi.Input[int] buffer_size: Automatically control the creation interval of delivery tasks and set the upper limit of an OSS object size (calculated in uncompressed), unit: `MB`.
        :param pulumi.Input[str] compress_type: OSS data storage compression method, support: none, snappy. Among them, none means that the original data is not compressed, and snappy means that the data is compressed using the snappy algorithm, which can reduce the storage space usage of the `OSS Bucket`.
        :param pulumi.Input[str] format: Storage format, only supports three types: `json`, `parquet`, `csv`.
               **According to the different format, please select the following parameters**
               - format = `json`
               `json_enable_tag` - (Optional) Whether to deliver the label.
               - format = `csv`
               `csv_config_delimiter` - (Optional) Separator configuration in csv configuration format.
               `csv_config_columns` - (Optional) Field configuration in csv configuration format.
               `csv_config_nullidentifier` - (Optional) Invalid field content.
               `csv_config_quote` - (Optional) Escape character under csv configuration.
               `csv_config_header` - (Optional) Indicates whether to write the field name to the CSV file, the default value is `false`.
               `csv_config_linefeed` - (Optional) lineFeed in csv configuration.
               - format = `parquet`
               `parquet_config` - (Optional) Configure to use parquet storage format.
               `name` - (Required) The name of the key.
               `type` - (Required) Type of configuration name.
        :param pulumi.Input[str] logstore_name: The name of the log logstore.
        :param pulumi.Input[str] oss_bucket: The name of the oss bucket.
        :param pulumi.Input[str] oss_prefix: The data synchronized from Log Service to OSS will be stored in this directory of Bucket.
        :param pulumi.Input[str] path_format: The OSS Bucket directory is dynamically generated according to the creation time of the shipper task, it cannot start with a forward slash `/`, the default value is `%Y/%m/%d/%H/%M`.
        :param pulumi.Input[str] project_name: The name of the log project. It is the only in one Alicloud account.
        :param pulumi.Input[str] role_arn: Used for access control, the OSS Bucket owner creates the role mark, such as `acs:ram::13234:role/logrole`
        :param pulumi.Input[str] shipper_name: Delivery configuration name, it can only contain lowercase letters, numbers, dashes `-` and underscores `_`. It must start and end with lowercase letters or numbers, and the name must be 2 to 128 characters long.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OssShipperState.__new__(_OssShipperState)

        __props__.__dict__["buffer_interval"] = buffer_interval
        __props__.__dict__["buffer_size"] = buffer_size
        __props__.__dict__["compress_type"] = compress_type
        __props__.__dict__["csv_config_columns"] = csv_config_columns
        __props__.__dict__["csv_config_delimiter"] = csv_config_delimiter
        __props__.__dict__["csv_config_header"] = csv_config_header
        __props__.__dict__["csv_config_linefeed"] = csv_config_linefeed
        __props__.__dict__["csv_config_nullidentifier"] = csv_config_nullidentifier
        __props__.__dict__["csv_config_quote"] = csv_config_quote
        __props__.__dict__["format"] = format
        __props__.__dict__["json_enable_tag"] = json_enable_tag
        __props__.__dict__["logstore_name"] = logstore_name
        __props__.__dict__["oss_bucket"] = oss_bucket
        __props__.__dict__["oss_prefix"] = oss_prefix
        __props__.__dict__["parquet_configs"] = parquet_configs
        __props__.__dict__["path_format"] = path_format
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["role_arn"] = role_arn
        __props__.__dict__["shipper_name"] = shipper_name
        return OssShipper(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bufferInterval")
    def buffer_interval(self) -> pulumi.Output[int]:
        """
        How often is it delivered every interval.
        """
        return pulumi.get(self, "buffer_interval")

    @property
    @pulumi.getter(name="bufferSize")
    def buffer_size(self) -> pulumi.Output[int]:
        """
        Automatically control the creation interval of delivery tasks and set the upper limit of an OSS object size (calculated in uncompressed), unit: `MB`.
        """
        return pulumi.get(self, "buffer_size")

    @property
    @pulumi.getter(name="compressType")
    def compress_type(self) -> pulumi.Output[Optional[str]]:
        """
        OSS data storage compression method, support: none, snappy. Among them, none means that the original data is not compressed, and snappy means that the data is compressed using the snappy algorithm, which can reduce the storage space usage of the `OSS Bucket`.
        """
        return pulumi.get(self, "compress_type")

    @property
    @pulumi.getter(name="csvConfigColumns")
    def csv_config_columns(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "csv_config_columns")

    @property
    @pulumi.getter(name="csvConfigDelimiter")
    def csv_config_delimiter(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "csv_config_delimiter")

    @property
    @pulumi.getter(name="csvConfigHeader")
    def csv_config_header(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "csv_config_header")

    @property
    @pulumi.getter(name="csvConfigLinefeed")
    def csv_config_linefeed(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "csv_config_linefeed")

    @property
    @pulumi.getter(name="csvConfigNullidentifier")
    def csv_config_nullidentifier(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "csv_config_nullidentifier")

    @property
    @pulumi.getter(name="csvConfigQuote")
    def csv_config_quote(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "csv_config_quote")

    @property
    @pulumi.getter
    def format(self) -> pulumi.Output[str]:
        """
        Storage format, only supports three types: `json`, `parquet`, `csv`.
        **According to the different format, please select the following parameters**
        - format = `json`
        `json_enable_tag` - (Optional) Whether to deliver the label.
        - format = `csv`
        `csv_config_delimiter` - (Optional) Separator configuration in csv configuration format.
        `csv_config_columns` - (Optional) Field configuration in csv configuration format.
        `csv_config_nullidentifier` - (Optional) Invalid field content.
        `csv_config_quote` - (Optional) Escape character under csv configuration.
        `csv_config_header` - (Optional) Indicates whether to write the field name to the CSV file, the default value is `false`.
        `csv_config_linefeed` - (Optional) lineFeed in csv configuration.
        - format = `parquet`
        `parquet_config` - (Optional) Configure to use parquet storage format.
        `name` - (Required) The name of the key.
        `type` - (Required) Type of configuration name.
        """
        return pulumi.get(self, "format")

    @property
    @pulumi.getter(name="jsonEnableTag")
    def json_enable_tag(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "json_enable_tag")

    @property
    @pulumi.getter(name="logstoreName")
    def logstore_name(self) -> pulumi.Output[str]:
        """
        The name of the log logstore.
        """
        return pulumi.get(self, "logstore_name")

    @property
    @pulumi.getter(name="ossBucket")
    def oss_bucket(self) -> pulumi.Output[str]:
        """
        The name of the oss bucket.
        """
        return pulumi.get(self, "oss_bucket")

    @property
    @pulumi.getter(name="ossPrefix")
    def oss_prefix(self) -> pulumi.Output[Optional[str]]:
        """
        The data synchronized from Log Service to OSS will be stored in this directory of Bucket.
        """
        return pulumi.get(self, "oss_prefix")

    @property
    @pulumi.getter(name="parquetConfigs")
    def parquet_configs(self) -> pulumi.Output[Optional[Sequence['outputs.OssShipperParquetConfig']]]:
        return pulumi.get(self, "parquet_configs")

    @property
    @pulumi.getter(name="pathFormat")
    def path_format(self) -> pulumi.Output[str]:
        """
        The OSS Bucket directory is dynamically generated according to the creation time of the shipper task, it cannot start with a forward slash `/`, the default value is `%Y/%m/%d/%H/%M`.
        """
        return pulumi.get(self, "path_format")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[str]:
        """
        The name of the log project. It is the only in one Alicloud account.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Output[Optional[str]]:
        """
        Used for access control, the OSS Bucket owner creates the role mark, such as `acs:ram::13234:role/logrole`
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter(name="shipperName")
    def shipper_name(self) -> pulumi.Output[str]:
        """
        Delivery configuration name, it can only contain lowercase letters, numbers, dashes `-` and underscores `_`. It must start and end with lowercase letters or numbers, and the name must be 2 to 128 characters long.
        """
        return pulumi.get(self, "shipper_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBackupPoliciesResult',
    'AwaitableGetBackupPoliciesResult',
    'get_backup_policies',
    'get_backup_policies_output',
]

@pulumi.output_type
class GetBackupPoliciesResult:
    """
    A collection of values returned by getBackupPolicies.
    """
    def __init__(__self__, db_cluster_id=None, id=None, output_file=None, policies=None):
        if db_cluster_id and not isinstance(db_cluster_id, str):
            raise TypeError("Expected argument 'db_cluster_id' to be a str")
        pulumi.set(__self__, "db_cluster_id", db_cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)

    @property
    @pulumi.getter(name="dbClusterId")
    def db_cluster_id(self) -> str:
        return pulumi.get(self, "db_cluster_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetBackupPoliciesPolicyResult']:
        return pulumi.get(self, "policies")


class AwaitableGetBackupPoliciesResult(GetBackupPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackupPoliciesResult(
            db_cluster_id=self.db_cluster_id,
            id=self.id,
            output_file=self.output_file,
            policies=self.policies)


def get_backup_policies(db_cluster_id: Optional[str] = None,
                        output_file: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackupPoliciesResult:
    """
    This data source provides the Click House Backup Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.147.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.clickhouse.get_backup_policies(db_cluster_id="example_value")
    pulumi.export("clickHouseBackupPolicyId1", example.policies[0].id)
    ```


    :param str db_cluster_id: The db cluster id.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['dbClusterId'] = db_cluster_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:clickhouse/getBackupPolicies:getBackupPolicies', __args__, opts=opts, typ=GetBackupPoliciesResult).value

    return AwaitableGetBackupPoliciesResult(
        db_cluster_id=pulumi.get(__ret__, 'db_cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        policies=pulumi.get(__ret__, 'policies'))
def get_backup_policies_output(db_cluster_id: Optional[pulumi.Input[str]] = None,
                               output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBackupPoliciesResult]:
    """
    This data source provides the Click House Backup Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.147.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.clickhouse.get_backup_policies(db_cluster_id="example_value")
    pulumi.export("clickHouseBackupPolicyId1", example.policies[0].id)
    ```


    :param str db_cluster_id: The db cluster id.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['dbClusterId'] = db_cluster_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:clickhouse/getBackupPolicies:getBackupPolicies', __args__, opts=opts, typ=GetBackupPoliciesResult)
    return __ret__.apply(lambda __response__: GetBackupPoliciesResult(
        db_cluster_id=pulumi.get(__response__, 'db_cluster_id'),
        id=pulumi.get(__response__, 'id'),
        output_file=pulumi.get(__response__, 'output_file'),
        policies=pulumi.get(__response__, 'policies')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PrivateZoneArgs', 'PrivateZone']

@pulumi.input_type
class PrivateZoneArgs:
    def __init__(__self__, *,
                 access_region_id: pulumi.Input[str],
                 cen_id: pulumi.Input[str],
                 host_region_id: pulumi.Input[str],
                 host_vpc_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a PrivateZone resource.
        :param pulumi.Input[str] access_region_id: The access region. The access region is the region of the cloud resource that accesses the PrivateZone service through CEN.
        :param pulumi.Input[str] cen_id: The ID of the CEN instance.
        :param pulumi.Input[str] host_region_id: The service region. The service region is the target region of the PrivateZone service to be accessed through CEN.
        :param pulumi.Input[str] host_vpc_id: The VPC that belongs to the service region.
               
               ->**NOTE:** The "cen.PrivateZone" resource depends on the related "cen.InstanceAttachment" resource.
        """
        pulumi.set(__self__, "access_region_id", access_region_id)
        pulumi.set(__self__, "cen_id", cen_id)
        pulumi.set(__self__, "host_region_id", host_region_id)
        pulumi.set(__self__, "host_vpc_id", host_vpc_id)

    @property
    @pulumi.getter(name="accessRegionId")
    def access_region_id(self) -> pulumi.Input[str]:
        """
        The access region. The access region is the region of the cloud resource that accesses the PrivateZone service through CEN.
        """
        return pulumi.get(self, "access_region_id")

    @access_region_id.setter
    def access_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "access_region_id", value)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> pulumi.Input[str]:
        """
        The ID of the CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter(name="hostRegionId")
    def host_region_id(self) -> pulumi.Input[str]:
        """
        The service region. The service region is the target region of the PrivateZone service to be accessed through CEN.
        """
        return pulumi.get(self, "host_region_id")

    @host_region_id.setter
    def host_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "host_region_id", value)

    @property
    @pulumi.getter(name="hostVpcId")
    def host_vpc_id(self) -> pulumi.Input[str]:
        """
        The VPC that belongs to the service region.

        ->**NOTE:** The "cen.PrivateZone" resource depends on the related "cen.InstanceAttachment" resource.
        """
        return pulumi.get(self, "host_vpc_id")

    @host_vpc_id.setter
    def host_vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "host_vpc_id", value)


@pulumi.input_type
class _PrivateZoneState:
    def __init__(__self__, *,
                 access_region_id: Optional[pulumi.Input[str]] = None,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 host_region_id: Optional[pulumi.Input[str]] = None,
                 host_vpc_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering PrivateZone resources.
        :param pulumi.Input[str] access_region_id: The access region. The access region is the region of the cloud resource that accesses the PrivateZone service through CEN.
        :param pulumi.Input[str] cen_id: The ID of the CEN instance.
        :param pulumi.Input[str] host_region_id: The service region. The service region is the target region of the PrivateZone service to be accessed through CEN.
        :param pulumi.Input[str] host_vpc_id: The VPC that belongs to the service region.
               
               ->**NOTE:** The "cen.PrivateZone" resource depends on the related "cen.InstanceAttachment" resource.
        :param pulumi.Input[str] status: The status of the PrivateZone service. Valid values: ["Creating", "Active", "Deleting"].
        """
        if access_region_id is not None:
            pulumi.set(__self__, "access_region_id", access_region_id)
        if cen_id is not None:
            pulumi.set(__self__, "cen_id", cen_id)
        if host_region_id is not None:
            pulumi.set(__self__, "host_region_id", host_region_id)
        if host_vpc_id is not None:
            pulumi.set(__self__, "host_vpc_id", host_vpc_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accessRegionId")
    def access_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The access region. The access region is the region of the cloud resource that accesses the PrivateZone service through CEN.
        """
        return pulumi.get(self, "access_region_id")

    @access_region_id.setter
    def access_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_region_id", value)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter(name="hostRegionId")
    def host_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The service region. The service region is the target region of the PrivateZone service to be accessed through CEN.
        """
        return pulumi.get(self, "host_region_id")

    @host_region_id.setter
    def host_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_region_id", value)

    @property
    @pulumi.getter(name="hostVpcId")
    def host_vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The VPC that belongs to the service region.

        ->**NOTE:** The "cen.PrivateZone" resource depends on the related "cen.InstanceAttachment" resource.
        """
        return pulumi.get(self, "host_vpc_id")

    @host_vpc_id.setter
    def host_vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_vpc_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the PrivateZone service. Valid values: ["Creating", "Active", "Deleting"].
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class PrivateZone(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_region_id: Optional[pulumi.Input[str]] = None,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 host_region_id: Optional[pulumi.Input[str]] = None,
                 host_vpc_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This topic describes how to configure PrivateZone access.
        PrivateZone is a VPC-based resolution and management service for private domain names.
        After you set a PrivateZone access, the Cloud Connect Network (CCN) and Virtual Border Router (VBR) attached to a CEN instance can access the PrivateZone service through CEN.

        For information about CEN Private Zone and how to use it, see [Manage CEN Private Zone](https://www.alibabacloud.com/help/en/cloud-enterprise-network/latest/api-cbn-2017-09-12-routeprivatezoneincentovpc).

        > **NOTE:** Available since v1.83.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.get_regions(current=True)
        example = alicloud.vpc.Network("example",
            vpc_name="tf_example",
            cidr_block="172.17.3.0/24")
        example_instance = alicloud.cen.Instance("example",
            cen_instance_name="tf_example",
            description="an example for cen")
        example_instance_attachment = alicloud.cen.InstanceAttachment("example",
            instance_id=example_instance.id,
            child_instance_id=example.id,
            child_instance_type="VPC",
            child_instance_region_id=default.regions[0].id)
        default_private_zone = alicloud.cen.PrivateZone("default",
            access_region_id=default.regions[0].id,
            cen_id=example_instance_attachment.instance_id,
            host_region_id=default.regions[0].id,
            host_vpc_id=example.id)
        ```

        ## Import

        CEN Private Zone can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/privateZone:PrivateZone example cen-abc123456:cn-hangzhou
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_region_id: The access region. The access region is the region of the cloud resource that accesses the PrivateZone service through CEN.
        :param pulumi.Input[str] cen_id: The ID of the CEN instance.
        :param pulumi.Input[str] host_region_id: The service region. The service region is the target region of the PrivateZone service to be accessed through CEN.
        :param pulumi.Input[str] host_vpc_id: The VPC that belongs to the service region.
               
               ->**NOTE:** The "cen.PrivateZone" resource depends on the related "cen.InstanceAttachment" resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PrivateZoneArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This topic describes how to configure PrivateZone access.
        PrivateZone is a VPC-based resolution and management service for private domain names.
        After you set a PrivateZone access, the Cloud Connect Network (CCN) and Virtual Border Router (VBR) attached to a CEN instance can access the PrivateZone service through CEN.

        For information about CEN Private Zone and how to use it, see [Manage CEN Private Zone](https://www.alibabacloud.com/help/en/cloud-enterprise-network/latest/api-cbn-2017-09-12-routeprivatezoneincentovpc).

        > **NOTE:** Available since v1.83.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.get_regions(current=True)
        example = alicloud.vpc.Network("example",
            vpc_name="tf_example",
            cidr_block="172.17.3.0/24")
        example_instance = alicloud.cen.Instance("example",
            cen_instance_name="tf_example",
            description="an example for cen")
        example_instance_attachment = alicloud.cen.InstanceAttachment("example",
            instance_id=example_instance.id,
            child_instance_id=example.id,
            child_instance_type="VPC",
            child_instance_region_id=default.regions[0].id)
        default_private_zone = alicloud.cen.PrivateZone("default",
            access_region_id=default.regions[0].id,
            cen_id=example_instance_attachment.instance_id,
            host_region_id=default.regions[0].id,
            host_vpc_id=example.id)
        ```

        ## Import

        CEN Private Zone can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/privateZone:PrivateZone example cen-abc123456:cn-hangzhou
        ```

        :param str resource_name: The name of the resource.
        :param PrivateZoneArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PrivateZoneArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_region_id: Optional[pulumi.Input[str]] = None,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 host_region_id: Optional[pulumi.Input[str]] = None,
                 host_vpc_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PrivateZoneArgs.__new__(PrivateZoneArgs)

            if access_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'access_region_id'")
            __props__.__dict__["access_region_id"] = access_region_id
            if cen_id is None and not opts.urn:
                raise TypeError("Missing required property 'cen_id'")
            __props__.__dict__["cen_id"] = cen_id
            if host_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'host_region_id'")
            __props__.__dict__["host_region_id"] = host_region_id
            if host_vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'host_vpc_id'")
            __props__.__dict__["host_vpc_id"] = host_vpc_id
            __props__.__dict__["status"] = None
        super(PrivateZone, __self__).__init__(
            'alicloud:cen/privateZone:PrivateZone',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_region_id: Optional[pulumi.Input[str]] = None,
            cen_id: Optional[pulumi.Input[str]] = None,
            host_region_id: Optional[pulumi.Input[str]] = None,
            host_vpc_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'PrivateZone':
        """
        Get an existing PrivateZone resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_region_id: The access region. The access region is the region of the cloud resource that accesses the PrivateZone service through CEN.
        :param pulumi.Input[str] cen_id: The ID of the CEN instance.
        :param pulumi.Input[str] host_region_id: The service region. The service region is the target region of the PrivateZone service to be accessed through CEN.
        :param pulumi.Input[str] host_vpc_id: The VPC that belongs to the service region.
               
               ->**NOTE:** The "cen.PrivateZone" resource depends on the related "cen.InstanceAttachment" resource.
        :param pulumi.Input[str] status: The status of the PrivateZone service. Valid values: ["Creating", "Active", "Deleting"].
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PrivateZoneState.__new__(_PrivateZoneState)

        __props__.__dict__["access_region_id"] = access_region_id
        __props__.__dict__["cen_id"] = cen_id
        __props__.__dict__["host_region_id"] = host_region_id
        __props__.__dict__["host_vpc_id"] = host_vpc_id
        __props__.__dict__["status"] = status
        return PrivateZone(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessRegionId")
    def access_region_id(self) -> pulumi.Output[str]:
        """
        The access region. The access region is the region of the cloud resource that accesses the PrivateZone service through CEN.
        """
        return pulumi.get(self, "access_region_id")

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> pulumi.Output[str]:
        """
        The ID of the CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="hostRegionId")
    def host_region_id(self) -> pulumi.Output[str]:
        """
        The service region. The service region is the target region of the PrivateZone service to be accessed through CEN.
        """
        return pulumi.get(self, "host_region_id")

    @property
    @pulumi.getter(name="hostVpcId")
    def host_vpc_id(self) -> pulumi.Output[str]:
        """
        The VPC that belongs to the service region.

        ->**NOTE:** The "cen.PrivateZone" resource depends on the related "cen.InstanceAttachment" resource.
        """
        return pulumi.get(self, "host_vpc_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the PrivateZone service. Valid values: ["Creating", "Active", "Deleting"].
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEnterpriseLogicDatabasesResult',
    'AwaitableGetEnterpriseLogicDatabasesResult',
    'get_enterprise_logic_databases',
    'get_enterprise_logic_databases_output',
]

@pulumi.output_type
class GetEnterpriseLogicDatabasesResult:
    """
    A collection of values returned by getEnterpriseLogicDatabases.
    """
    def __init__(__self__, databases=None, id=None, ids=None, output_file=None):
        if databases and not isinstance(databases, list):
            raise TypeError("Expected argument 'databases' to be a list")
        pulumi.set(__self__, "databases", databases)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def databases(self) -> Sequence['outputs.GetEnterpriseLogicDatabasesDatabaseResult']:
        """
        A list of Logic Database Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "databases")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Logic Database IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetEnterpriseLogicDatabasesResult(GetEnterpriseLogicDatabasesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnterpriseLogicDatabasesResult(
            databases=self.databases,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file)


def get_enterprise_logic_databases(ids: Optional[Sequence[str]] = None,
                                   output_file: Optional[str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnterpriseLogicDatabasesResult:
    """
    This data source provides DMS Enterprise Logic Database available to the user. [What is Logic Database](https://www.alibabacloud.com/help/en/dms/developer-reference/api-dms-enterprise-2018-11-01-createlogicdatabase).

    > **NOTE:** Available since v1.195.0.


    :param Sequence[str] ids: A list of Logic Database IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:dms/getEnterpriseLogicDatabases:getEnterpriseLogicDatabases', __args__, opts=opts, typ=GetEnterpriseLogicDatabasesResult).value

    return AwaitableGetEnterpriseLogicDatabasesResult(
        databases=pulumi.get(__ret__, 'databases'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_enterprise_logic_databases_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                          output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnterpriseLogicDatabasesResult]:
    """
    This data source provides DMS Enterprise Logic Database available to the user. [What is Logic Database](https://www.alibabacloud.com/help/en/dms/developer-reference/api-dms-enterprise-2018-11-01-createlogicdatabase).

    > **NOTE:** Available since v1.195.0.


    :param Sequence[str] ids: A list of Logic Database IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:dms/getEnterpriseLogicDatabases:getEnterpriseLogicDatabases', __args__, opts=opts, typ=GetEnterpriseLogicDatabasesResult)
    return __ret__.apply(lambda __response__: GetEnterpriseLogicDatabasesResult(
        databases=pulumi.get(__response__, 'databases'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FolderArgs', 'Folder']

@pulumi.input_type
class FolderArgs:
    def __init__(__self__, *,
                 folder_name: pulumi.Input[str],
                 parent_folder_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Folder resource.
        :param pulumi.Input[str] folder_name: The name of the folder. The name must be 1 to 24 characters in length and can contain letters, digits, underscores (_), periods (.), and hyphens (-).
        :param pulumi.Input[str] parent_folder_id: The ID of the parent folder. If not set, the system default value will be used.
        """
        pulumi.set(__self__, "folder_name", folder_name)
        if parent_folder_id is not None:
            pulumi.set(__self__, "parent_folder_id", parent_folder_id)

    @property
    @pulumi.getter(name="folderName")
    def folder_name(self) -> pulumi.Input[str]:
        """
        The name of the folder. The name must be 1 to 24 characters in length and can contain letters, digits, underscores (_), periods (.), and hyphens (-).
        """
        return pulumi.get(self, "folder_name")

    @folder_name.setter
    def folder_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "folder_name", value)

    @property
    @pulumi.getter(name="parentFolderId")
    def parent_folder_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the parent folder. If not set, the system default value will be used.
        """
        return pulumi.get(self, "parent_folder_id")

    @parent_folder_id.setter
    def parent_folder_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parent_folder_id", value)


@pulumi.input_type
class _FolderState:
    def __init__(__self__, *,
                 folder_name: Optional[pulumi.Input[str]] = None,
                 parent_folder_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Folder resources.
        :param pulumi.Input[str] folder_name: The name of the folder. The name must be 1 to 24 characters in length and can contain letters, digits, underscores (_), periods (.), and hyphens (-).
        :param pulumi.Input[str] parent_folder_id: The ID of the parent folder. If not set, the system default value will be used.
        """
        if folder_name is not None:
            pulumi.set(__self__, "folder_name", folder_name)
        if parent_folder_id is not None:
            pulumi.set(__self__, "parent_folder_id", parent_folder_id)

    @property
    @pulumi.getter(name="folderName")
    def folder_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the folder. The name must be 1 to 24 characters in length and can contain letters, digits, underscores (_), periods (.), and hyphens (-).
        """
        return pulumi.get(self, "folder_name")

    @folder_name.setter
    def folder_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder_name", value)

    @property
    @pulumi.getter(name="parentFolderId")
    def parent_folder_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the parent folder. If not set, the system default value will be used.
        """
        return pulumi.get(self, "parent_folder_id")

    @parent_folder_id.setter
    def parent_folder_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parent_folder_id", value)


class Folder(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 folder_name: Optional[pulumi.Input[str]] = None,
                 parent_folder_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Resource Manager Folder resource. A folder is an organizational unit in a resource directory. You can use folders to build an organizational structure for resources.
        For information about Resource Manager Foler and how to use it, see [What is Resource Manager Folder](https://www.alibabacloud.com/help/en/doc-detail/111221.htm).

        > **NOTE:** Available since v1.82.0.

        > **NOTE:** A maximum of five levels of folders can be created under the root folder.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        example = alicloud.resourcemanager.Folder("example", folder_name=f"{name}-{default['result']}")
        ```

        ## Import

        Resource Manager Folder can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:resourcemanager/folder:Folder example fd-u8B321****	
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] folder_name: The name of the folder. The name must be 1 to 24 characters in length and can contain letters, digits, underscores (_), periods (.), and hyphens (-).
        :param pulumi.Input[str] parent_folder_id: The ID of the parent folder. If not set, the system default value will be used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FolderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Resource Manager Folder resource. A folder is an organizational unit in a resource directory. You can use folders to build an organizational structure for resources.
        For information about Resource Manager Foler and how to use it, see [What is Resource Manager Folder](https://www.alibabacloud.com/help/en/doc-detail/111221.htm).

        > **NOTE:** Available since v1.82.0.

        > **NOTE:** A maximum of five levels of folders can be created under the root folder.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        example = alicloud.resourcemanager.Folder("example", folder_name=f"{name}-{default['result']}")
        ```

        ## Import

        Resource Manager Folder can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:resourcemanager/folder:Folder example fd-u8B321****	
        ```

        :param str resource_name: The name of the resource.
        :param FolderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FolderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 folder_name: Optional[pulumi.Input[str]] = None,
                 parent_folder_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FolderArgs.__new__(FolderArgs)

            if folder_name is None and not opts.urn:
                raise TypeError("Missing required property 'folder_name'")
            __props__.__dict__["folder_name"] = folder_name
            __props__.__dict__["parent_folder_id"] = parent_folder_id
        super(Folder, __self__).__init__(
            'alicloud:resourcemanager/folder:Folder',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            folder_name: Optional[pulumi.Input[str]] = None,
            parent_folder_id: Optional[pulumi.Input[str]] = None) -> 'Folder':
        """
        Get an existing Folder resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] folder_name: The name of the folder. The name must be 1 to 24 characters in length and can contain letters, digits, underscores (_), periods (.), and hyphens (-).
        :param pulumi.Input[str] parent_folder_id: The ID of the parent folder. If not set, the system default value will be used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FolderState.__new__(_FolderState)

        __props__.__dict__["folder_name"] = folder_name
        __props__.__dict__["parent_folder_id"] = parent_folder_id
        return Folder(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="folderName")
    def folder_name(self) -> pulumi.Output[str]:
        """
        The name of the folder. The name must be 1 to 24 characters in length and can contain letters, digits, underscores (_), periods (.), and hyphens (-).
        """
        return pulumi.get(self, "folder_name")

    @property
    @pulumi.getter(name="parentFolderId")
    def parent_folder_id(self) -> pulumi.Output[str]:
        """
        The ID of the parent folder. If not set, the system default value will be used.
        """
        return pulumi.get(self, "parent_folder_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTopicsResult',
    'AwaitableGetTopicsResult',
    'get_topics',
    'get_topics_output',
]

@pulumi.output_type
class GetTopicsResult:
    """
    A collection of values returned by getTopics.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, instance_id=None, name_regex=None, names=None, output_file=None, tags=None, topics=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if topics and not isinstance(topics, list):
            raise TypeError("Expected argument 'topics' to be a list")
        pulumi.set(__self__, "topics", topics)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of topic names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        """
        A map of tags assigned to the Ons instance.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def topics(self) -> Sequence['outputs.GetTopicsTopicResult']:
        """
        A list of topics. Each element contains the following attributes:
        """
        return pulumi.get(self, "topics")


class AwaitableGetTopicsResult(GetTopicsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTopicsResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            instance_id=self.instance_id,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            tags=self.tags,
            topics=self.topics)


def get_topics(enable_details: Optional[bool] = None,
               ids: Optional[Sequence[str]] = None,
               instance_id: Optional[str] = None,
               name_regex: Optional[str] = None,
               output_file: Optional[str] = None,
               tags: Optional[Mapping[str, str]] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTopicsResult:
    """
    This data source provides a list of ONS Topics in an Alibaba Cloud account according to the specified filters.

    > **NOTE:** Available in 1.53.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "onsInstanceName"
    topic = config.get("topic")
    if topic is None:
        topic = "onsTopicDatasourceName"
    default = alicloud.rocketmq.Instance("default",
        instance_name=name,
        remark="default_ons_instance_remark")
    default_topic = alicloud.rocketmq.Topic("default",
        topic_name=topic,
        instance_id=default.id,
        message_type=0,
        remark="dafault_ons_topic_remark")
    topics_ds = alicloud.rocketmq.get_topics_output(instance_id=default_topic.instance_id,
        name_regex=topic,
        output_file="topics.txt")
    pulumi.export("firstTopicName", topics_ds.topics[0].topic_name)
    ```


    :param Sequence[str] ids: A list of topic IDs to filter results.
    :param str instance_id: ID of the ONS Instance that owns the topics.
    :param str name_regex: A regex string to filter results by the topic name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param Mapping[str, str] tags: A map of tags assigned to the Ons instance.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['instanceId'] = instance_id
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:rocketmq/getTopics:getTopics', __args__, opts=opts, typ=GetTopicsResult).value

    return AwaitableGetTopicsResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        tags=pulumi.get(__ret__, 'tags'),
        topics=pulumi.get(__ret__, 'topics'))
def get_topics_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                      ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                      instance_id: Optional[pulumi.Input[str]] = None,
                      name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                      output_file: Optional[pulumi.Input[Optional[str]]] = None,
                      tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTopicsResult]:
    """
    This data source provides a list of ONS Topics in an Alibaba Cloud account according to the specified filters.

    > **NOTE:** Available in 1.53.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "onsInstanceName"
    topic = config.get("topic")
    if topic is None:
        topic = "onsTopicDatasourceName"
    default = alicloud.rocketmq.Instance("default",
        instance_name=name,
        remark="default_ons_instance_remark")
    default_topic = alicloud.rocketmq.Topic("default",
        topic_name=topic,
        instance_id=default.id,
        message_type=0,
        remark="dafault_ons_topic_remark")
    topics_ds = alicloud.rocketmq.get_topics_output(instance_id=default_topic.instance_id,
        name_regex=topic,
        output_file="topics.txt")
    pulumi.export("firstTopicName", topics_ds.topics[0].topic_name)
    ```


    :param Sequence[str] ids: A list of topic IDs to filter results.
    :param str instance_id: ID of the ONS Instance that owns the topics.
    :param str name_regex: A regex string to filter results by the topic name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param Mapping[str, str] tags: A map of tags assigned to the Ons instance.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['instanceId'] = instance_id
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:rocketmq/getTopics:getTopics', __args__, opts=opts, typ=GetTopicsResult)
    return __ret__.apply(lambda __response__: GetTopicsResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        tags=pulumi.get(__response__, 'tags'),
        topics=pulumi.get(__response__, 'topics')))
